( cd usr/lib64 ; rm -rf libglib-1.2.so.0 )
( cd usr/lib64 ; ln -sf libglib-1.2.so.0.0.10 libglib-1.2.so.0 )
( cd usr/lib64 ; rm -rf libglib.so )
( cd usr/lib64 ; ln -sf libglib-1.2.so.0.0.10 libglib.so )
( cd usr/lib64 ; rm -rf libgmodule-1.2.so.0 )
( cd usr/lib64 ; ln -sf libgmodule-1.2.so.0.0.10 libgmodule-1.2.so.0 )
( cd usr/lib64 ; rm -rf libgmodule.so )
( cd usr/lib64 ; ln -sf libgmodule-1.2.so.0.0.10 libgmodule.so )
( cd usr/lib64 ; rm -rf libgthread-1.2.so.0 )
( cd usr/lib64 ; ln -sf libgthread-1.2.so.0.0.10 libgthread-1.2.so.0 )
( cd usr/lib64 ; rm -rf libgthread.so )
( cd usr/lib64 ; ln -sf libgthread-1.2.so.0.0.10 libgthread.so )
# Install the info files for this package
if [ -x usr/bin/install-info ]
then
   usr/bin/install-info --info-dir=/usr/info /usr/info/glib.info.gz 2>/dev/null
fi

